.. _spkg_comm:

comm: Jupyter Python Comm implementation, for usage in ipykernel, xeus-python etc.
==================================================================================

Description
-----------

Jupyter Python Comm implementation, for usage in ipykernel, xeus-python etc.

License
-------

BSD 3-Clause License

Upstream Contact
----------------

https://pypi.org/project/comm/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_pip`
- :ref:`spkg_traitlets`

Version Information
-------------------

package-version.txt::

    0.2.2

version_requirements.txt::

    comm

Equivalent System Packages
--------------------------

(none known)
